#
# spec file for package python-neutronclient
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-neutronclient
Version:        11.3.1
Release:        1.1
Summary:        Python API and CLI for OpenStack Neutron
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://docs.openstack.org/python-neutronclient
Source0:        https://files.pythonhosted.org/packages/source/p/python-neutronclient/python-neutronclient-11.3.1.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python3-cliff >= 3.4.0
BuildRequires:  python3-fixtures
BuildRequires:  python3-keystoneauth1 >= 3.8.0
BuildRequires:  python3-keystoneclient >= 3.8.0
BuildRequires:  python3-netaddr >= 0.7.18
BuildRequires:  python3-os-client-config >= 1.28.0
BuildRequires:  python3-osc-lib >= 1.12.0
BuildRequires:  python3-oslo.i18n >= 3.15.3
BuildRequires:  python3-oslo.log >= 3.36.0
BuildRequires:  python3-oslo.serialization >= 2.18.0
BuildRequires:  python3-oslo.utils >= 3.33.0
BuildRequires:  python3-oslotest
BuildRequires:  python3-osprofiler
BuildRequires:  python3-pbr >= 2.0.0
BuildRequires:  python3-requests-mock
BuildRequires:  python3-stestr
BuildRequires:  python3-testscenarios
BuildRequires:  python3-testtools
BuildArch:      noarch

%description
Client library and command line utility for interacting with OpenStack
Neutron's API.

%package -n python3-neutronclient
Summary:        Python API and CLI for OpenStack Neutron
Requires:       python3-Babel
Requires:       python3-cliff >= 3.4.0
Requires:       python3-debtcollector >= 1.2.0
Requires:       python3-iso8601 >= 0.1.11
Requires:       python3-keystoneauth1 >= 3.8.0
Requires:       python3-keystoneclient >= 3.8.0
Requires:       python3-netaddr >= 0.7.18
Requires:       python3-osc-lib >= 1.12.0
Requires:       python3-oslo.i18n >= 3.15.3
Requires:       python3-oslo.serialization >= 2.18.0
Requires:       python3-oslo.utils >= 3.33.0
Requires:       python3-pbr >= 2.0.0
Requires:       python3-requests >= 2.14.2
Requires:       python3-simplejson
%if 0%{?suse_version}
Obsoletes:      python2-neutronclient < 7.1.0
%endif

%description -n python3-neutronclient
Client library and command line utility for interacting with OpenStack
Neutron's API.

This package contains the Python 3.x module.

%package -n python-neutronclient-doc
Summary:        Documentation for OpenStack Neutron API Client
Group:          Documentation/HTML
BuildRequires:  python3-Sphinx
BuildRequires:  python3-openstackdocstheme
BuildRequires:  python3-reno

%description -n python-neutronclient-doc
Client library and command line utility for interacting with OpenStack
Neutron's API.

%prep
%autosetup -p1 -n %{name}-%{version}
%py_req_cleanup

%build
%{py3_build}

# Build HTML docs and man page
PBR_VERSION=11.3.1 %sphinx_build -b html doc/source doc/build/html
PBR_VERSION=11.3.1 %sphinx_build -b man doc/source doc/build/man
rm -r doc/build/html/.{doctrees,buildinfo}

%install
%{py3_install}

%check
%{openstack_stestr_run}

%files -n python3-neutronclient
%license LICENSE
%{python3_sitelib}/neutronclient
%{python3_sitelib}/*.egg-info

%files -n python-neutronclient-doc
%doc doc/build/html README.rst
%license LICENSE

%changelog
* Tue Sep  3 2024 cloud-devel@suse.de
- update to version 11.3.1
  - reno: Update master for unmaintained/victoria
  - Fix insert and remove rule from firewall policy
  - reno: Update master for unmaintained/xena
  - Update master for stable/2024.1
  - reno: Update master for unmaintained/zed
  - reno: Update master for unmaintained/wallaby
  - BGPVPN: Fix resource comparison
* Sun Mar 24 2024 cloud-devel@suse.de
- update to version 11.2.0
  - reno: Update master for unmaintained/yoga
  - Add note to prevent new features to be added (CLI and Python bindings)
  - Bump hacking
* Sun Jan 14 2024 cloud-devel@suse.de
- update to version 11.1.0
  - OSC: Remove VPNAAS V2 calls to neutronclient
  - OSC: Remove SFC V2 calls to neutronclient
  - Tox4: add allowlist_externals where necessary
  - Update master for stable/2023.2
  - Update master for stable/yoga
  - Add support to floating ip port forwarding
  - OSC: Remove BGP calls to neutronclient
  - Switch to 2023.1 Python3 unit tests and generic template name
  - Skip B105 pep8 error: hardcoded passwords
  - Remove 'bgp speaker show dragents'
  - Remove the CLI code from the Neutron client.
  - Drop lower-constraints.txt and its testing
  - OSC: Remove BGPVPN calls to neutronclient
  - Update master for stable/zed
  - Update master for stable/2023.1
  - Fix help sentence in network log create --enable
  - BGPVPN: make resource_association method calls logic simpler
  - OSC: Remove FWAAS V2 calls to neutronclient
  - Update python testing as per zed cycle teting runtime
  - Imported Translations from Zanata
  - Remove CLI warning message
  - Drop unused simplejson
  - Add warning and reno for SDK
  - Move network trunk commands from python-neutronclient
* Tue May 24 2022 cloud-devel@suse.de
- update to version 7.8.0
  - Replace deprecated assertDictContainsSubset
  - Update master for stable/xena
  - Fix lower-constraints and neutronclient-functional job
  - Add support for minimum packet rate rule to the client
  - Add CURD actions for packet rate limit rule
  - Add support for 'smart-nic' vnic-type
  - Update python testing classifier
  - Add Python3 yoga unit tests
* Tue Oct 26 2021 cloud-devel@suse.de
- update to version 7.6.0
  - Fix lower constraints
  - Add Python3 xena unit tests
  - Update master for stable/wallaby
  - Ussuri+ is python3 only and update python to python3
  - Replace getargspec with getfullargspec
  - setup.cfg: Replace dashes with underscores
  - Support passing mTLS certificate/key to HTTPClient
  - Changed minversion in tox to 3.18.0
  - Set ML2/OVS backend explicitly for functional job
  - Skip metering functional tests when metering extension is not enabled
  - Use yaml.safe_load instead of yaml.load
  - Add a release note on deprecation for removal of neutron CLI
  - tests: change safe_hasattr to hasattr
  - Set when deprecated neutron client CLI will be removed
* Sun May  2 2021 cloud-devel@suse.de
- update to version 7.3.0
  - Add Python3 wallaby unit tests
  - Dep's should be restricted by tox-constraints
  - Fix lower-constraints for Focal
  - Update master for stable/victoria
  - Update requirements URLs in tox config
  - remove unicode from code
* Fri Oct  9 2020 cloud-devel@suse.de
- update to version 7.2.1
  - lower-constraints: Drop os-testr, mox3
  - Add Python3 victoria unit tests
  - Fix hacking min version to 3.0.1
  - Use unittest.mock instead of mock
  - Allow 4byte ASNs in dynamic routing client
  - Use unittest.mock instead of third party mock
  - Stop to use the __future__ module.
  - Fix description of bgp speaker set arg
  - Remove usage of six
  - Bump default tox env from py37 to py38
  - Switch to newer openstackdocstheme and reno versions
  - zuul: native Zuul v3 version of the grenade job
  - Remove translation sections from setup.cfg
  - Add segments client code
  - Update master for stable/ussuri
  - Add py38 package metadata
  - Remove Babel from requirements
  - Add aggressive negotiation mode for ikepolicy
* Tue May 12 2020 cloud-devel@suse.de
- update to version 7.1.1
  - Remove 'public' and 'private' parameters in fwaas_v2
  - Switch to Ussuri jobs
  - Fix pep8 errors with hacking 2.0.0
  - Drop python 2.7 support
  - Avoid py36 error when printing unicode chars in a stream
  - Drop python3 hack for XML serializer
  - fix a typo
  - PDF documentation build
  - Add support for port bindings
  - Cleanup py27 support
  - Update master for stable/train
  - Drop lib-forward-testing
  - Convert exception to string before passing it in
  - Move grenade neutron-lib job to py3 and in python-neutronclient repo
  - Replace 'bgp speaker show dragents' with 'bgp dragent list'
* Mon Mar 23 2020 Dirk Mueller <dmueller@suse.com>
- add obsoletes
* Wed Mar 11 2020 Dirk Mueller <dmueller@suse.com>
- switch to python 3.x only build
* Wed Oct  9 2019 cloud-devel@suse.de
- update to version 6.14.0
  - Switch functional job to python3
  - Add router add/remove extra routes operations
  - Replace git.openstack.org URLs with opendev.org URLs
  - Fix string in header
  - OpenDev Migration Patch
  - Dropping the py35 testing
  - doc: Remove prompt from python binding examples
  - Blacklist bandit 1.6.0 due to directory exclusion bug
  - Add friendly event hints for logging
  - Replace openstack.org git:// URLs with https://
  - Update master for stable/stein
  - Use secure sha256 instead of sha1
  - Improve help text
  - Add Python 3 Train unit tests
  - Convert legacy functional jobs to zuulv3
  - Run functional test correctly
  - add python 3.7 unit test job
* Mon Apr  8 2019 cloud-devel@suse.de
- update to version 6.12.0
  - Fix api version handling, which completely breaks the client
  - Switch to stestr
  - Update json module to jsonutils
  - Update mailinglist from dev to discuss
  - Fix broken unittests
  - Add subnet onboard CLI
  - import zuul job settings from project-config
  - Support of the boolean advertise_extra_routes
  - Add B303 into list of skipped bandit plugins
  - Ensure API calls for subnets are in URL length limit
  - Add release note link in README
  - Adds the destination and source fwg to fwr
  - Change openstack-dev to openstack-discuss
  - Fix docstring in method list_networks_on_dhcp_agent
  - Update reno for stable/rocky
  - Don't quote {posargs} in tox.ini
  - add python 3.6 unit test job
  - Add support for querying quotas with usage
  - Add Python 3.6 classifier to setup.cfg
  - Update hacking version to 1.1
  - Update links in README
  - add lib-forward-testing-python3 test job
  - Fix docstring in method list_routers_on_l3_agent
  - switch documentation job to new PTI
  - Update min tox version to 2.3.2
  - fix tox python3 overrides
  - Remove basepython from [flake8] section
  - Consolidate irrelevant files added for py3 project
  - Add bandit to pep8 gate
  - Use templates for cover and lower-constraints
  - [log] Add 'firewall_group' as a loggable resource type for logging
* Wed Nov 28 2018 cloud-devel@suse.de
- update to version 6.9.1
  - Update UPPER_CONSTRAINTS_FILE for stable/rocky
  - Update .gitreview for stable/rocky
  - Fix broken unittests
- remove 0001-Fix-broken-unittests.patch (merged)
* Mon Sep  3 2018 cloud-devel@suse.de
- update to version 6.9.0
  - Replace insecure function eval
  - Remove mox/mox3 usage from test_cli20_port.py
  - Update reno for stable/queens
  - Add oslo.log to requirements.txt
  - Remove mox/mox3 usage from fw modules
  - Remove mox/mox3 usage from lb modules
  - Remove PyPI downloads
  - Fix the assertion of standard error text
  - Remove mox/mox3 usage from test_cli20_securitygroup.py
  - Fix incompatible requirement in lower-constraints
  - Remove mox/mox3 usage from test_cli20_subnet.py
  - Remove mox/mox3 usage from test_name_or_id.py
  - Rename python-openstacksdk to openstacksdk
  - osc, bgpvpn: add support for 'local_pref' BGPVPN attribute
  - Remove mox/mox3 from test_cli20_agentschedulers.py
  - Set or unset port pair group failed
  - Fix pep8 error
  - Trivial: Update pypi url to new url
  - Remove mox/mox3 usage from test_cli20.py
  - Fix list bgp speaker by agent ID
  - Consume column utils from osc-lib
  - Follow the new PTI for document build
  - Drop neutronclient-specific cliff sphinx extension
  - Remove bogus ID column from ListRoutesAdvertisedBySpeaker
  - Remove mox3 from test-requirements.txt
  - Remove mox/mox3 usage from bgp
  - Remove mox/mox3 usage from test_quota
  - add lower-constraints job
  - Remove mox/mox3 usage from test_cli20_tag
  - Remove mox/mox3 usage from test_cli20_network.py
  - Remove mox/mox3 from test_cli20_address_scope.py
  - Updated from global requirements
  - Remove mox/mox3 usage from test_cli20_subnetpool.py
  - Enable VPNaaS functional tests in the neutronclient gate
- add  0001-Fix-broken-unittests.patch
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Mon Feb 12 2018 cloud-devel@suse.de
- update to version 6.7.0 (bsc#1078607)
  - Add Logging commands for OSC plugin
  - Add VPNaaS commands for OSC plugin
  - Consume tempest CLIClient keystone v3 support
  - Remove a workaround for osc-lib in FWaaS UT
  - Define IpAddressAlreadyAllocated exception
  - Pass headers to httpclient
  - Add commands to support BGP VPN route control new API extension
  - VNI support in BGPVPN CLI
  - Add correlation type "nsh" to both PPs and PCs
  - Fix broken links
  - Updated from global requirements
  - Add 'revision_number' to update_* API
* Mon Jan 15 2018 cloud-devel@suse.de
- update to version 6.6.0
  - Use generic $USER variable for functional tests
  - SFC plugin: fix all list commands
  - SFC plugin: preserve chain order in set/unset commands
  - Update reno for stable/pike
  - SFC plugin: fix port chain set commands
  - Remove setting of version/release from releasenotes
  - Define shell.COMMANDS explicitly to avoid random UT failure
  - SFC plugin: fix dictionary parameters
  - Avoid tox_install.sh for constraints support
  - Dynamic routing CLIs OSC transition
  - Added 'tap_enabled' parameter for Port-pair-group
  - Add Service Graphs networking-sfc resource
  - Add missing correlation type "mpls" to port pair
  - Updated from global requirements
  - Make func test work with keystone v3 only
* Mon Aug  7 2017 cloud-devel@suse.de
- update to version 6.5.0
  - Supports adding tags for port, router, subnet, subnetpool
  - Call mock.patch.stopall in OSC unit tests
  - remove explicit global_request_id handling from session client
  - Add optional_keys and required_keys to --subport argument
  - Remove unused object
  - Don't sort the fw_rule order in OSC
  - Allow global_request_id in Client constructor
  - Add profiling support to neutronclient
  - Use entry points to define neutron CLI commands
  - Python 3.4 support is removed
  - Add BGP VPN OSC commands
  - Update reno for stable/ocata
  - x-openstack-request-id logged twice in logs
  - FWaaS OSC plugin: Use python logging instead of oslo.log
  - Allow to specify tenant_id in subnetpool-create
  - doc: Improve network CLI page
  - Now empty tags are not added to Networks
  - doc: autogenerate neutron CLI reference
  - Revert "HAProxy uses milliseconds for its timeout values."
  - Handle log message interpolation by the logger
  - Do not append .json to sending URL
  - [FWaaS] Migrate 'public' attribute to 'shared'
  - Fix label of allowed-address-pair ip_address
  - doc: use new config options of openstackdocstheme
  - Don't decode empty response body
  - Use flake8-import-order plugin
  - Set project_id column header to Project
  - Be explicit about the identity plugin required in unit tests
  - Convert gate_hook to devstack-tools
  - doc: autogenerate OSC plugin command reference
  - Machine-readable output for JSON/YAML format
  - BGP unit test 'auth-type' errors
  - Change documentation about UpdateQuota class
  - Enable warning-is-error in doc build
  - move existing content into the new standard structure
  - Unable to add classless-static-route in extra_dhcp_opt extension
  - Fix using wrong status code in some tests
  - Fixed a bunch of spacing
  - Add SFC cli for OSC plugin
  - doc: Fix warning
  - Update the documentation link for doc migration
  - Add plug-in summary for osc doc
  - Refactor of Network tests
  - Drop deprecated neutronclient.i18n wrapper
  - CLI implementation should raise CommandError
  - Remove log translations
  - Populate shell.COMMANDS dict not to break CLI extension UT
  - FWaaS UT: Fake rule should return value returned from API
  - doc: Patch acceptance policy after neutron CLI deprecation
  - Drop MANIFEST.in - it's not needed by pbr
  - [Fix gate]Update test requirement
  - switch to openstackdocstheme
  - Replace uuid.uuid4() with uuidutils.generate_uuid()
  - Trivial Fix:fix typo in .pylintrc file
  - SFC plugin: fix flow classifier list display
  - Updated from global requirements
* Mon Feb 13 2017 cloud-devel@suse.de
- update to version 6.1.0:
  - Replace 'MagicMock' with 'Mock'
  - Fix Quota Support for HMs
  - Disable VPNaaS functional tests in the neutronclient gate
  - Show team and repo badges on README
  - remove unused LOG
  - Correct DisassociatingHealthmonitor help messages
  - Enable release notes translation
  - Devref: Transition to OSC update
  - Decode exception parameters to expand exception message properly
  - Use method is_valid_cidr from oslo.utils
  - Update reno for stable/newton
  - Replace lb_method with lb_algorithm
  - Add FWaaS V2 commands for OSC plugin
  - Simplify clearing session-persistence
  - Clean imports in code
  - Modify the help of connection-limit
  - FWaaSv2 - Enable to specify 'any' for protocol
  - Add rbac_policy to quota resources
  - Show tenant_id in *-list by admin
  - [VPNaaS] Add support for sha2-384 and sha2-512
  - Use raw values when non-table formatter is used
  - Disallow specifying name for meter-label-rule
  - Add documentation for FWaaS v2 OSC plugin commands
  - OSC plugin: catch up with osc-lib 1.0 interface change
  - Replace 'os' to 'openstack' for all command example
  - FWaaS - Adds an argument into find_resource
  - fix one spelling mistake
  - Added --enable-snat option for router-gateway-set
  - Clarify how to do client-side development for repos in neutron governance
  - Fix a typo
  - Deprecate neutron CLI
  - Return proper error code for CLI failure
  - Use correct cmd_parser
  - Modify key for 'qos-minimum-bandwidth-rule-list' reponse
  - Add common utilities for OSC plugin implementation
  - Handle keystoneauth exceptions in retry logic
  - Use six.python_2_unicode_compatible for NeutronException.__str__
  - Updated from global requirements
  - The testcase's name may be inapposite. It is better to use 'delete', instead of 'delele'.
* Mon Sep  5 2016 tbechtold@suse.com
  update to version 6.0.0
  * Fix the problem of "qos-bandwidth-limit-rule-show"
  * Improve Help message of VPN Update CLI
  * Drop LBaaS v1 functional tests
  * Add segment as an attribute to subnet in client
  * Move advanced service functional tests to functional-adv-svcs
  * Fix prompt message for qos-bandwidth-limit-rule-create
  * Add flavor argument to router
  * Add quota support for LB and Listeners
  * Add possible updatable options to net-update CLI
  * Use upper constraints for all jobs in tox.ini
  * Devref: Newton mid-cycle updates for transition to OSC
  * Remove discover from test-requirements
  * Add 'shared' option to neutron address-scope-update
  * Trivial correction in variable name
  * Add client exception for HostNotCompatibleWithFixedIps
  * Add support to expose default quotas for tenants
  * quota-update to return an error msg for 0 args
  * Add trunk commands to openstackclient
  * Update OSC transition status
  * Add Python 3.5 classifier and venv
  * Provide client bindings for DELETE method of auto-allocated-topology extension
  * Add QoS egress minimum bandwidth rule to neutronclient
  * Remove admin-state-down from lbaas-member-update
  * Fix the problem of "qos-dscp-marking-rule-show"
  * Add long option to network trunk list command
  * Make trunk commands handle description for trunk resources
  * Add documentation for OSC plugin commands
  * Do not check stderr output from shell
  * Remove case dependancy for user inputs
  * Make trunk commands handle timestamps for trunk resources
  * Enable DeprecationWarning in test environments
  * Remove environment defaults
  * Sync tools/tox_install.sh
  * Update docs to use Identity v3
  * Log request-id for each api call
  * Add support for Bulk Delete in NeutronClient
  * Move find_resource family to API binding layer
  * Make find_resourceid_by_id public in python binding class
  * Improve help messages for NeutronClient
  * Updated from global requirements
  * Fix problem of RBAC command arguments
* Tue Aug  9 2016 tbechtold@suse.com
- update to 5.0.0:
  * Fix string interpolation at logging call
  * Updated from global requirements
  * Add functional test hook for fwaas command
  * HAProxy uses milliseconds for its timeout values
  * Base OSC plugin support
  * Make USER_AGENT variable global
  * Trivial: missing comma in the docs
  * Fixed --insecure not taking effect when specified
  * Fix the problem of mox in test_shell.py
  * Trivial Fix: Fix typo
  * improve readme contents
  * Add no-shared option to qos-policy-update command
  * Add in missing translations
  * Trivial: ignore openstack/common in flake8 exclude list
  * Update for API bindings
  * Remove unnecessary executable permissions
  * Update tempest_lib to tempest.lib
  * Constraint tox targets with upper-constraints.txt
  * Make purge supports dvr router's interface
  * Switched from fixtures.MonkeyPatch to mock.patch
  * tests: removed mocking for Client.get_attr_metadata
  * Update the home-page with developer documentation
  * Address pairs help missing space
  * Devref: Add dynamic routing to OSC transition
  * Support sha256 for vpn-ikepolicy and vpn-ipsecpolicy
  * Fixes unclear error when no --pool-prefix given
  * Added missing help text for 'purge' command
  * Fix random failure of security group unit test
  * Remove the last remaining vendor code
* Mon Aug  1 2016 tbechtold@suse.com
- update to 4.2.0:
  * Change try..except to assertRaises in UT
  * Updated from global requirements
  * Change --no-gateway help text
  * Log SHA1 hash of X-Auth-Token value
  * Remove APIParamsCall decorator
  * Fix assertNotEqual parameters
  * organize the release notes consistently
  * Update reno for stable/mitaka
  * Add parser options for description on resources
  * Add release note of critial TypeError fix
  * Fix TypeError with error message
  * Adding DSCP marking changes to neutronclient
  * Update relnote on fix of bug 1450414
  * Support dry-run option for auto-allocated-topology
  * fix: can't get authentication with os-token and os-url
  * refactor: Merge all debug logging at the beginning of take_action
  * refactor: Avoid overriding run() in cliff command
  * Add tags support
  * Fixed typos in securitygroup.py
  * Add commands for Network IP Availability
  * Support cleanup of tenant resources with a single API call
  * Reflecting L7 content rules capability in LBaaS
  * LBaaS updates to reflect shared pools feature
  * Misleading output when network is not found
  * add rbac support for qos-policies
  * Devref Update: Transition to OpenStack Client
  * Add wrapper classes for return-request-id-to-caller
  * BGP Dynamic Routing: neutronclient changes
  * Add use_default_subnetpool to subnet create requests
  * Do not print 'Created' message when using non-table formatter
  * Ensure to use exception per status code for all cases
  * Use instanceof instead of type
  * Add DNS integration support to the client
  * Improve str2dict key validation to avoid wrong keys
  * Fix the exception when ID/Name not found
  * Fix typo in the help of net-list
  * Fix typos in the docstrings
  * Provide argument filtering in neutron *-list
  * Client bindings for Get-me-a-network
  * "neutron help firewall-rule-update" info updated
  * Show all updatable options in (fw/fw-policy)-update CLI
  * Allow UPPER case in protocol/action for FW Rule
  * Make metavar usage consistent
  * Update translation setup
  * Fix code-block for python code in doc
  * Trivial Update on ReleaseNotes
  * Remove inconsistency from vpn help text
  * Remove argparse from requirements
  * Add code for load balancer status tree
  * Add support for default subnetpools API
  * Fix typo in docstrings
  * refactor: Get rid of usage of get_data in favor of take_action
  * refactor: Drop meaningless 'api' attribute from NeutronCommand class
  * refactor: Remove usage of useless command.command.OpenStackCommand
  * Convert remaining use of neutronclient.i18n to _i18n
  * Remove 'u' displayed before subnetpool-list's prefixes
  * Add support for ip_version on AddressScope create
  * Enhance the help info of "neutron router-gateway-set"
  * Adding a lowercase converter in utils.py
  * Add some items to the release notes
  * Devref: Transition to OpenStack Client
  * port: Add 'direct-physical' as a valid vnic-type
  * Drop unused TableFormater code
  * test: fix option in port test
  * Support pagination listing in client extension
  * Add protocol value options to sg-rule-create
  * improve tox -e cover
  * Use _i18n instead of i18n
  * Add method to retrieve loadbalancer stats
  * Support for Name field in Members and HMs
  * Show availability_zone info in CLI neutron agent-list
  * Delete python bytecode before every test run
  * Reworded nargs='?' explanation for better clarity
  * Drop py33 support
  * Fixed connection_limit and added UT
  * Add help information of 'firewall-rule-create'
  * Allow tenant_id positional in quota syntax
  * Fix H405 violations
  * Deprecated tox -downloadcache option removed
  * Remove nuage plugin from client
  * Adding missing headers to the devref documents
  * Allow lower case protocol values
  * Allow passing version as '2' as well as '2.0'
  * Remove XML support
  * Add availability_zone CLI
  * Remove extra space from VPN validator exception messages
  * Add CLI option guideline
  * Add description of extra args in CLI
  * Add os-client-config to CLI usage
  * Add more contents about CLI usage
  * Setup for translation
  * Do not include reno releasenotes in normal documentation
  * Add release notes for changes since 3.0.0 release
  * Fix a column name "protocol/port" to "port/protocol"
  * Remove py26 support
  * Reorganize documentation structure
  * Trivial: Fix a typo in class ListCommand
  * Use sphinx-build -W in [docs] target
  * Add 'baremetal' as an allowed vnic type
  * Add reno for release notes management
  * Move the old release notes to a separate file
  * Do not allow name lookups on RBAC policies
  * Add route options to neutron router-update
  * Revert "Revert "Remove Cisco-specific neutron client commands""
  * Improve neutron-client error message output
  * CLI support for VPNaaS multiple local subnets
  * Add flavor argument to loadbalancer v2 create
  * Drop cliff-tablib from test-requirements.txt
  * Add Neutron flavor framework CLI
  * Create floating IP on a specific subnet ID
  * Documentation error in show_bandwidth_limit_rule
  * Use os-client-config and keystoneauth1 in shell
  * Adding a generate_default_ethertype_function
  * Use clouds.yaml from devstack for functional tests
  * Revert parent_id and obj_id parameter order
  * Fix arg order of assertEqual and use assertTrue
  * Let devstack-gate handle the gate hook timeout
  * Ensure to decode bytes or fail
  * Add allowed-address-pairs to port-update
  * neutron v2 command module cleanup (2)
  * neutron v2 command module cleanup #1
  * CRUD for VPN endpoint group API
  * Define non_admin_status_resources in each test
  * Fix extend_show parameter name
  * Py3k compliance: check for bytes when making a string
  * Enable VPN test cases
- update _service and switch to upstream spec file
* Thu Mar  3 2016 tbechtold@suse.com
- update to 3.1.1:
  * Ensure to decode bytes or fail
  * Do not allow name lookups on RBAC policies
  * Updated from global requirements
  * Updated from global requirements
  * Revert parent_id and obj_id parameter order
  * Updated from global requirements
  * Let devstack-gate handle the gate hook timeout
  * Py3k compliance: check for bytes when making a string
  * Update .gitreview for stable/liberty
* Sun Oct  4 2015 tbechtold@suse.com
- update to 3.1.0:
  * Updated from global requirements
  * Revert "Remove Cisco-specific neutron client commands"
  * Updated from global requirements
  * Remove Cisco-specific neutron client commands
* Mon Sep 14 2015 tbechtold@suse.com
- update to 3.0.0:
  * Remove NEC plugin specific commands
  * Update path to subunit2html in post_test_hook
  * Updated from global requirements
  * Add REJECT rule on FWaaS Client
  * Update tls_container_id to tls_container_ref
  * Updated from global requirements
  * Support CLI changes for QoS (2/2)
  * Support QoS neutron-client (1/2)
  * Clear the extension requirement
  * Updated from global requirements
  * Make subnetpool-list show correct address scope column
  * Fix find_resourceid_by_name call for address scopes
  * Add extension name to extension's command help text line
  * Adding registration interface for non_admin_status_resources
  * Add document for entry point in setup.cfg
  * Create hooks for running functional test
  * Support Command line changes for Address Scope
  * Remove --shared option from firewall-create
  * Disable failing vpn tests
  * Support RBAC neutron-client changes
  * Remove newlines from request and response log
  * Updated from global requirements
  * Updated from global requirements
  * Devref documentation for client command extension support
  * Support CLI changes for associating subnetpools and address-scopes
  * Remove unused AlreadyAttachedClient
  * Avoid overwriting parsed_args
  * Determine ip version during subnet create
  * Call UnsetStub/VerifyAll properly for tests with exceptions
  * Updated from global requirements
  * Support resource plurals not ending in 's'
  * Updated from global requirements
  * Revert "Add '--router:external' option to 'net-create'"
  * Updated from global requirements
  * Updated from global requirements
  * Fixes indentation for bash completion script
  * Allow bash completion script to work with BSD sed
  * Add alternative login description in neutronclient docs
  * Updated from global requirements
  * Raise user-friendly exceptions in str2dict
  * LBaaS v2: Fix listing pool members
  * Fix functional tests and tox 2.0 errors
- Adjust Requires according to requirements.txt
* Mon Aug 31 2015 tbechtold@suse.com
- update to 2.6.0:
  * Updated from global requirements
  * Allow setting router's external ip(s)
  * Drop use of 'oslo' namespace package
  * Updated from global requirements
  * Add functional test for subnet create
  * Fix Python client library for Neutron
  * Update README to work with release tools
  * Uncap library requirements for liberty
  * Add --binding-profile to port-create
  * Fix invalid error message in neutron-cli
- Adjust Requires according to requirements.txt
* Wed Aug  5 2015 dmueller@suse.com
- add %%name-rpmlintrc
* Fri Apr 24 2015 tbechtold@suse.com
- Use %%{version} in source
* Thu Apr 23 2015 tbechtold@suse.com
- Switch to version 2.4.0
* Wed Apr 22 2015 tbechtold@suse.com
- Add missing Requires
* Fri Apr 17 2015 cloud-devel@suse.de
- Update to version python-neutronclient-2.4.0.post1:
  * Uncap library requirements for liberty
* Fri Apr 10 2015 cloud-devel@suse.de
- Update to version python-neutronclient-2.4.0:
  2.4.0
  * Fix one remaining E125 error and remove it from ignore list
  * Add Neutron subnetpool API
  * Revert "Remove unused AlreadyAttachedClient"
* Thu Apr  9 2015 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.11.post62:
  * Allow passing None for subnetpool
  * Support fwaasrouterinsertion extension
  * Make secgroup rules more readable in security-group-show
  * Fix E265 block comment should start with '# '
  * Remove author tag
  * Update hacking to 0.10
* Wed Apr  8 2015 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.11.post50:
  * Add Neutron subnet-create with subnetpool
  * Adding VLAN Transparency support to neutronclient
* Sat Apr  4 2015 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.11.post47:
  * 'neutron port-create' missing help info for --binding:vnic-type
* Tue Mar 31 2015 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.11.post46:
  * Prefer argparse mutual exclusion
* Sun Mar 29 2015 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.11.post44:
  * Add HA router state to l3-agent-list-hosting-router
* Tue Mar 24 2015 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.11.post42:
  * Updated from global requirements
* Mon Mar 23 2015 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.11.post40:
  * security-group-rule-list: show all info of rules briefly
  * Show rules in handy format in security-group-list
* Sun Mar 22 2015 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.11.post36:
  * Fix failures when calling list operations using Python binding
* Thu Mar 19 2015 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.11.post34:
  * Add commands from extensions to available commands
* Thu Mar 19 2015 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.11.post32:
  * Updates pool session persistence options
  * Updating lbaas cli for TLS
  * Added client calls for the lbaas v2 agent scheduler
* Wed Mar 18 2015 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.11.post26:
  * Remove unused AlreadyAttachedClient
  * Change Creates to Create in help text
* Fri Mar 13 2015 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.11.post22:
  * Copy functional tests from tempest cli
* Thu Mar 12 2015 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.11.post21:
  * exec permission to port_test_hook.sh
  * Reinstate Max URI length checking to V2_0 Client
* Tue Mar 10 2015 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.11.post17:
  * Add post_test_hook for functional tests
  * First pass at tempest-lib based functional testing
  * Add OS_TEST_PATH to testr
  * Ignore order of query parameters when compared in MyUrlComparator
* Fri Mar  6 2015 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.11.post11:
  * Fixed pool and health monitor create bugs
  * Honor allow_names in *-update command
* Thu Feb 26 2015 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.11.post7:
  * Client command extension support
* Wed Feb 25 2015 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.11.post5:
  * Fix lbaas-loadbalancer-create with no --name
  * Make some auth error messages more verbose
* Sun Feb 22 2015 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.11.post1:
  2.3.11
  * Updated from global requirements
* Thu Feb 19 2015 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.10.post62:
  * Add unit tests for agentscheduler related commands
* Wed Feb 18 2015 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.10.post60:
  * Fix for incorrect parameter in user-id error message in shell.py
  * Add ip_version to extra dhcp opts
  * Split base function of v2_0.Client into a separate class
* Sat Feb 14 2015 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.10.post54:
  * Updated from global requirements
* Thu Feb 12 2015 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.10.post53:
  * Fix CSV formatting of fixed_ips field in port-list command
* Sun Feb  8 2015 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.10.post51:
  * Reverse order of tests to avoid incompatibility
* Thu Feb  5 2015 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.10.post49:
  * Implement LBaaS object model v2
  * Skip None id when getting security_group_ids
  * Utility method for boolean argument
  * Parameter support both id and name
  * Fix TypeError for six.text_type
  * Fix columns setup base on csv formatter
* Wed Feb  4 2015 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.10.post37:
  * Fix typo in test_cli20_agentschedulers filename
  * Updated from global requirements
* Wed Jan 21 2015 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.10.post34:
  * Add parser options for port-update and port-create
  * Add floating-ip-address to floatingip-create
  * Remove unreachable code from test_cli20 class
* Fri Jan 16 2015 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.10.post28:
  * Fix KeyError when filtering SG rule listing
  * Updated from global requirements
  * Parse provider network attributes in net_create
* Thu Jan 15 2015 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.10.post22:
  * Namespace of arguments is incorrectly used
  * Correct the bash completion of CLI
* Wed Jan 14 2015 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.10.post18:
  * Add '--router:external' option to 'net-create'
  * Use adapter from keystoneclient
  * Use requests_mock instead of mox
* Fri Jan  9 2015 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.10.post12:
  * Add Python 3 classifiers
* Thu Jan  8 2015 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.10.post10:
  * Fix True/False to accept Camel and Lower case
* Sun Dec 28 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.10.post8:
  * Workflow documentation is now in infra-manual
* Tue Dec 23 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.10.post6:
  * Updated from global requirements
  * Fix issues with Unicode compatibility for Py3
* Thu Dec 18 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.10.2:
  * firewall policy update for a rule is not working
* Wed Dec 17 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.10:
  2.3.10
  * subnet: allow --enable-dhcp=False/True syntax, again
* Tue Dec 16 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.9.61.g3751afd:
  * Router create distributed accepts lower case
  * Add unit tests for agent related commands
  * Use discovery fixture
  * Cleanup copy and pasted token
* Sun Dec 14 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.9.54.g56892bb:
  * Make help for agent-update more verbose
* Wed Dec  3 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.9.53.g19de15d:
  * Updated from global requirements
* Tue Dec  2 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.9.51.g8a77718:
  * fix the firewall rule arg split error
* Fri Nov 28 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.9.50.g11deb7f:
  * neutron port-list -f csv outputs poorly formatted JSON strings
* Fri Nov 21 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.9.48.g5067975:
  * Disable name support for lb-healthmonitor-* commands
  * Fix mixed usage of _
* Thu Nov 20 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.9.44.g4e88834:
  * Fixes neutronclient lb-member-show command
  * Don't allow update of ipv6-ra-mode and ipv6-address-mode
* Fri Oct 31 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.9.40.g9ed73c0:
  * Updated from global requirements
* Mon Oct 27 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.9.39.gc646818:
  * Updated from global requirements
  * Use graduated oslo libraries
  * Fix E113 hacking check
  * Fix E129 hacking check
  * Updated from global requirements
  * Remove extraneous vim editor configuration comments
* Fri Oct 17 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.9.30.geae3211:
  * Fix E128 hacking check
* Thu Oct 16 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.9.28.g35dbc97:
  * Bump hacking to 0.9.x series
* Wed Oct 15 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.9.26.g72c1473:
  * Add InvalidIpForNetworkClient exception
* Tue Oct 14 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.9.24.g170f8ca:
  * Leverage neutronclient.openstack.common.importutils import_class
* Mon Oct 13 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.9.22.g40c6172:
  * Add missing parameters to Client's docstring
  * Change "healthmonitor" to "health monitor" in help info
  * Correct 4xx/5xx response management in SessionClient
  * Change ipsecpolicies to 2 separate words: IPsec policies
  * handles keyboard interrupt
  * Use six.moves cStringIO instead of cStringIO
  * Replace httpretty with requests_mock
  * Fix to ensure endpoint_type is used by make_client()
  * Work toward Python 3.4 support and testing
  * Adds tty password entry for neutronclient
* Thu Oct  9 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.9.3.gb5f629f:
  * Don't get keystone session if using noauth
* Mon Oct  6 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.9.1.g8115c02:
  * Updated from global requirements
  2.3.9
* Thu Sep 18 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.8.2.gfa5642f:
  2.3.8
  * Fix Py3 compatibility issues
  * Improve help strings
* Tue Sep 16 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.7.28.g1aedb2e:
  * Narrow down except clause
  * Correct Content-Type/Accept management in HTTPClient/SessionClient
  * Allow to specify policy by name in firewall-update
  * Isolate tests from HTTP_PROXY, OS_REGION_NAME env vars
  * Clean-up shell run and run_subcommand methods
* Mon Sep 15 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.7.18.g88e8e8f:
  * Silence iso8601 debug messages in verbose mode
  * Stop using intersphinx
  * Updated from global requirements
  * Replace utils.dumps with jsonutils.dumps
  * neutronclient shows low-level logs in console screen
* Sat Sep 13 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.7.8.g5832a54:
  * Add L3 HA / VRRP support to CLI
* Fri Sep 12 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.7.6.ga85773c:
  * Unify doc-strings format
  * Small improve of str2dict function
* Tue Sep  9 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.7.2.g4bc3790:
  * Leverage openstack.common.jsonutils
  2.3.7
* Tue Sep  2 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.6.34.gf22dbd2:
  * Updated from global requirements
* Sun Aug 31 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.6.33.g76d5c1a:
  * Remove unnecessary get_status_code wrapper function
  * Avoid modifying default function arguments
* Fri Aug 29 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.6.29.gdee50ca:
  * Repeat add-tenant and remove-tenant option in cli
* Thu Aug 28 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.6.27.gdeb850b:
  * Fix CLI support for DVR, take 2
  * Refactor CreateRouter to use update_dict
* Fri Aug 22 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.6.25.g98d2135:
  * Rename --timeout param to --http-timeout
* Tue Aug 19 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.6.24.gb9bd695:
  * Fix listing security group rules
* Sat Aug 16 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.6.22.g035f18b:
  * Fix typo in cli help
  * Remove incorrect super() call
* Fri Aug 15 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.6.18.g8f59a30:
  * Print exception when verbose is over DEBUG_LEVEL
* Thu Aug 14 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.6.17.geca251c:
  * Remove "--disabled" for firewall create rule
* Wed Aug 13 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.6.15.g4e820b5:
  * Fix unit tests to succeed on any PYTHONHASHSEED
  * Provide support for nested objects
* Mon Aug 11 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.6.11.g7524234:
  * Add keystone v3 auth support
  * Updated from global requirements
  * Introduce shadow resources for NeutronCommands
  * Add option for retry number of connection attempts
* Mon Aug  4 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.6.4.g759acaf:
  * setup logger name of NeutronCommand automatically
  2.3.6
  * Python 3: compatibility of StringIO() and dict.iterkeys()
* Thu Jul 31 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.5.47.gabc54a0:
  * Improve the method find_resourceid_by_name_or_id
  * Update theme for docs
  * Add a tox job for generating docs
  * Add MacAddressInUseClient exception handling
  * Create new IPv6 attributes for Subnets by client
  * Python 3: use six.iteritems()
  * Some edits for help strings
  * Changed 'json' to 'JSON'
* Tue Jul 29 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.5.31.g65a6430:
  * Remove strict checking of encryption type
  * Add a new timeout option to set the HTTP Timeout
  * Fix for CLI message of agent disassociation
  * Pass timeout parameter to requests lib call
* Fri Jul 25 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.5.23.g6d5640c:
  * Revert "Fix CLI support for DVR"
  * Silences the output in CLI for connection info
* Tue Jul 22 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.5.20.ge059143:
  * Warn on tiny subnet
  * Suppress outputs in test_cli20_nsx_networkgateway
* Mon Jul 21 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.5.16.gbfec80a:
  * Fix CLI support for DVR
* Sat Jul 19 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.5.15.g03be2b4:
  * Add CLI Support for DVR
* Sat Jul 12 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.5.13.g2b3cf68:
  * Add CONTRIBUTING.rst
  * Found a useless comment
  * Changed 'xml' to 'XML'
* Fri Jul 11 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.5.7.g8a2349a:
  * Sync with oslo
* Fri Jun 27 2014 cloud-devel@suse.de
- Rebased patches:
  + 0001-Switch-over-to-mox3.patch dropped (merged upstream)
* Fri Jun 27 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.5.6.g3a25ff3:
  * Switch over to mox3
  2.3.5
  * debug level logs should not be translated
  * Updated from global requirements
* Thu Jun 26 2014 opensuse-packaging@opensuse.org
- Rebased patches:
  + 0001-Switch-over-to-mox3.patch (manually)
  Thu Jun 26 10:00:37 UTC 2014 -
- Update to version python-neutronclient-2.3.4.91.gc907df8:
  * Improve help strings
  * Ensure .status_code is defined for all NeutronClientExceptions
  * Set firewall_rules only after appending all rules
  * Improvements in neutron_test sanity tests script
* Mon Jun 16 2014 opensuse-packaging@opensuse.org
- Rebased patches:
  + 0001-Switch-over-to-mox3.patch (manually)
  Mon Jun 16 10:16:59 UTC 2014 -
- Update to version python-neutronclient-2.3.4.83.g1bce6e4:
  * Make neutronclient parse keystone v3 endpoints correctly
  * Add OverQuotaClient as exception to neutronclient
  * Synced jsonutils from oslo-incubator
* Tue Jun 10 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.4.77.g99f45d1:
  * removed usage of '... can be repeated.'
* Mon Jun  9 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.4.76.g4ac92cc:
  * added new column binary to the listing of agents
  * Python3: fix syntax issue in _encode_item()
* Sun Jun  8 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.4.72.g3ddc965:
  * Add ability to update certain attributes in a subnet
* Wed Jun  4 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.4.70.g6cec9fe:
  * Removed now unnecesary workaround for PyPy
* Wed May 28 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.4.68.g91613e0:
  * enable sorting support for agent listing
* Tue May 27 2014 dmueller@suse.com
- fix requires
- Update to version python-neutronclient-2.3.4.66.g91bea94:
  * Suppress expected help messages caused by wrong CLI inputs
* Fri May  9 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.4.65.gf6eba87:
  * Remove httplib2 requirement
* Thu May  1 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.4.63.g45ffced:
  * Updated from global requirements
* Mon Apr 28 2014 dmueller@suse.com
- Update to version python-neutronclient-2.3.4.62.gfa49aab:
  * Allow user ID for authentication
  * Use requests module for HTTP/HTTPS (bnc#869955)
* Wed Apr 23 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.4.58.ge135df7:
  * Updated from global requirements
* Tue Apr 22 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.4.57.g320e014:
  * Support packet_filter extension in NEC plugin
* Fri Apr 18 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.4.56.g1246cd9:
  * Updated from global requirements
  * Return response status reason on error
  * Suppress stdout/stderr in test_shell
  * session_persistence: invalid str2dict value: u''
* Tue Apr 15 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.4.48.g0ef9b8e:
  * Rearrange neutronclient exceptions for more easy use
* Tue Apr  8 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.4.46.g07bcee8:
  * Support building wheels (PEP-427)
* Thu Apr  3 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.4.44.g663f8bd:
  * Adds support for os-auth-strategy=noauth
* Thu Mar 27 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.4.43.g54d15e7:
  * Show the unknown auth stratey in neutron client
* Sat Mar 22 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.4.42.gdebd91b:
  * Work around pypy testing issue
  * Remove unused imports
  * Extending quota support neutron LBaaS entities
* Sat Mar 15 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.4.36.g5613ea7:
  * Empty file shouldn't contain copyright nor license
  * Updated from global requirements
  * CLI support for NSX gateway devices
  * Use six.moves.urllib.parse to replace urlparse
  * Enable to select specific network service type
  * Replace assertEqual(None, *) with assertIsNone in tests
* Tue Mar 11 2014 speilicke@suse.com
- Rebased patches:
  + 0001-Switch-over-to-mox3.patch (manually)
- Update to version python-neutronclient-2.3.4.25.g42f48fb:
  * Updated from global requirements
  * New exception when auth_url is not specified
  * Print human friendly string as an error message
* Thu Mar  6 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.4.19.g9d8ccad:
  * Python 3: fix a call to ugettext()
  * Adds delete of extra-dhcp-opt to the client
* Tue Mar  4 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.4.15.g43f7fa4:
  * Supporting Net-Partition as extension for Nuage plugin
* Mon Mar  3 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.4.13.g866d1e1:
  * Enable hacking H233 rule
* Wed Feb 26 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.4.11.gfba38c6:
  * Fix net-gateway-create help message
* Mon Feb 24 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.4.9.g0df7db0:
  * Add shared parameter for metering labels
  * Adding weight column to Neutron lb member list CLI
* Sat Feb 22 2014 dmueller@suse.com
- Update to version python-neutronclient-2.3.4.5.g0933fe0:
  * Unexpected response in agent-list command
  * Don't reuse 'body' for response data
  * Modify quota-list descripton
  * Remove vi modelines
  * Fixed a minor typo in a docstring
  * Use assertIn where appropriate
* Wed Feb 19 2014 cloud-devel@suse.de
- Update to version python-neutronclient-2.3.3.16.g3ba2d2e:
  * Work around for httplib2 retries on timeout
  * update coveragerc file
  * Mention --fixed-ip subnet_id=<..> in help message
* Thu Feb 13 2014 dmueller@suse.com
- added patches:
  * 0001-Switch-over-to-mox3.patch
* Thu Feb 13 2014 speilicke@suse.com
- Drop coverage (build)requires, we don't run pep8 tests
* Thu Feb 13 2014 dmueller@suse.com
- remove hacking dependency
* Tue Feb 11 2014 speilicke@suse.com
- Update to version python-neutronclient-2.3.3.11.gdf0f5d2:
  * Fixed get_auth_info() for pre-authenticated clients
  * Rename Nicira NVP to VMware NSX in neutronclient
  * Combine debug and verbose commandline options
- Replace git_tarballs source service with download_files and set_version
  + Use upstream URL as source (enables verification)
* Sun Jan 12 2014 opensuse-cloud@opensuse.org
- Update to version 2.3.3.6.g8aacb12:
  + Fix description of ListSubnet
* Fri Jan 10 2014 opensuse-cloud@opensuse.org
- Update to version 2.3.3.4.g6b44e60:
  + Remove an unused imported module
  + Misc typo in neutronclient
* Sat Jan  4 2014 opensuse-cloud@opensuse.org
- Update to version 2.3.2.4.gdf68d75:
  + Make compatible with Cliff (1.5.2)
* Thu Dec 26 2013 opensuse-cloud@opensuse.org
- Update to version 2.3.2.3.g2026ffd:
  + Remove start index 0 in range()
* Tue Dec 24 2013 opensuse-cloud@opensuse.org
- Update to version 2.3.2.1.g60800b1:
  + Remove a debugging print statement
* Sun Dec 15 2013 opensuse-cloud@opensuse.org
- Update to version 2.3.1.42.g39b1567:
  + Add -U to pip install command in tox.ini
* Fri Dec 13 2013 opensuse-cloud@opensuse.org
- Update to version 2.3.1.40.g19e1842:
  + Pin Sphinx to <1.2 in test-requirements
* Fri Dec  6 2013 opensuse-cloud@opensuse.org
- Update to version 2.3.1.39.g6d7d677:
  + Fix i18n messages in neutronclient
  + Updates .gitignore
  + Fix neutron port-create --no-security-groups
* Mon Dec  2 2013 opensuse-cloud@opensuse.org
- Update to version 2.3.1.35.g607645a:
  + Convert xrange to range
* Sat Nov 30 2013 opensuse-cloud@opensuse.org
- Update to version 2.3.1.33.g01982df:
  + Fix lb-healthmonitor-update to work with correct object
* Fri Nov 29 2013 opensuse-cloud@opensuse.org
- Update to version 2.3.1.31.gb298eb7:
  + [fwaas] Can now create disabled firewall rules
  + Handle IpAddressInUse with client exception
* Thu Nov 28 2013 opensuse-cloud@opensuse.org
- Update to version 2.3.1.27.g9a2754c:
  + Ignores swap files generated during file editing
* Tue Nov 26 2013 opensuse-cloud@opensuse.org
- Update to version 2.3.1.26.gc67eeee:
  + Log reason for connection failed exception
* Mon Nov 25 2013 dmueller@suse.com
- switch to python-setuptools
* Sun Nov 24 2013 opensuse-cloud@opensuse.org
- Update to version 2.3.1.24.g5b5aa1a:
  + Make HACKING.rst DRYer
* Sun Nov  3 2013 opensuse-cloud@opensuse.org
- Update to version 2.3.1.23.gfeda92f:
  + Fix status_code not passed in code
* Mon Oct 21 2013 opensuse-cloud@opensuse.org
- Update to version 2.3.1.22.ga8c5c65:
  + Add ability to reference pool by name in lb-pool-stats command
  + Change copyright headers from LLC to Foundation
* Sat Oct 19 2013 opensuse-cloud@opensuse.org
- Update to version 2.3.1.18.g9fc2ac9:
  + Updated from global requirements
* Tue Oct  8 2013 opensuse-cloud@opensuse.org
- Update to version 2.3.1.17.g1dd88b9:
  + Forcibly clear connection pool after every request
  + Adds ExternalIpAddressExhaustedClient exception
  + Updated from global requirements
  + Fix stable/grizzly gating for Neutron (aka Quantum)
* Wed Oct  2 2013 opensuse-cloud@opensuse.org
- Update to version 2.3.1.10.gc8dfa4b:
  + Fixes the display message for the insert/remove firewall rule CLI
* Tue Oct  1 2013 dmueller@suse.com
- add bash completion
* Tue Oct  1 2013 opensuse-cloud@opensuse.org
- Update to version 2.3.1.8.g16bf282:
  + Adds IpAddressGenerationFailureClient exception
* Thu Sep 26 2013 opensuse-cloud@opensuse.org
- Update to version 2.3.1.7.g15d5e50:
  + Update tox.ini to use new features
* Tue Sep 24 2013 opensuse-cloud@opensuse.org
- Update to version 2.3.1.6.g89936fa:
  + Remove openstack.common.exception usage
  + Update help string to match API doc
* Wed Sep 18 2013 opensuse-cloud@opensuse.org
- Update to version 2.3.1.2.ge61e846:
  + Client for metering extension
* Wed Sep 18 2013 dmueller@suse.com
- fix requires
* Mon Sep 16 2013 opensuse-cloud@opensuse.org
- Update to version 2.3.0.10.g030da0e:
  + Update cliff version to 1.4.3 in requirements.txt
* Thu Sep 12 2013 opensuse-cloud@opensuse.org
- Update to version 2.3.0.8.ga3f5d0a:
  + Fix cisco n1kv plugin cli option and help
* Sat Sep  7 2013 opensuse-cloud@opensuse.org
- Update to version 2.3.0.6.g920a5af:
  + Add provider attribute to lb-pool-create command
* Thu Sep  5 2013 opensuse-cloud@opensuse.org
- Update to version 2.3.0.4.gdb7b01d:
  + Allow 'any' option for protocol in the firewall rule
  + bp:pxeboot-ports, provide pxboot on ports
* Wed Sep  4 2013 opensuse-cloud@opensuse.org
- Update to version 2.2.6.33.gb1f348a:
  + Added support for running the tests under PyPy with tox
  + Sync test-requirements with global requirements
  + The "arg_value" was not getting checked for empty list
  + Use assertEqual instead of assertEquals
  + neutron router-gateway-set failed for non-admin users
  + Remove status field from the list of fields of Healthmonitor
* Tue Sep  3 2013 opensuse-cloud@opensuse.org
- Update to version 2.2.6.21.g375dcff:
  + Makes client always use provided endpoint_url
  + Add 'distributed' option to router-create command
  + Add multi-segment and trunk support to N1KV Neutron client
  + Move vpn unittest code to neutronclient.tests
  + Make _test_update_resource honor format
* Sat Aug 31 2013 opensuse-cloud@opensuse.org
- Update to version 2.2.6.11.g081b55b:
  + Fix H202 hacking check in VPN client
* Tue Aug 27 2013 opensuse-cloud@opensuse.org
- Update to version 2.2.6.10.gad59ba6:
  + VPN as a Service (VPNaaS) Client API
  + Merge with Oslo (master/ded9bd6)
* Thu Aug 22 2013 opensuse-cloud@opensuse.org
- Update to version 2.2.6.7.ge34a06a:
  + Add credentials and profile support to Neutron client
  + Improve help message of loadbalancer commands
  + Move tests back to neutronclient package
* Thu Aug  8 2013 speilicke@suse.com
- Update to version 2.2.6:
  + FWaaS Client and Cli
  + Sync with global requirements
  + Add get_attr for EXTED_PLURALS
- Fix _service regex
* Fri Jul 19 2013 dmueller@suse.com
- fix requires/provides/obsoletes
* Fri Jul 12 2013 opensuse-cloud@opensuse.org
- Update to version 2.2.4.8:
  + Allow user to specify None value to attributes
  + Remove commented out code
* Thu Jul 11 2013 opensuse-cloud@opensuse.org
- Update to version 2.2.4.4:
  + Don't convert httplib2 exceptions to status codes
* Tue Jul  9 2013 opensuse-cloud@opensuse.org
- Update to version 2.2.4.2:
  + Allow tenant ID for authentication
* Sun Jul  7 2013 dmueller@suse.com
- switch over to neutron git
* Sun Jul  7 2013 opensuse-cloud@opensuse.org
- Update to version 2.2.4.1:
  + Renamed quantum to neutron in .gitreview
* Thu Jul  4 2013 dmueller@suse.com
- renamed to python-neutronclient from python-quantumclient
* Thu Jul  4 2013 opensuse-cloud@opensuse.org
- Update to version 2.2.3.1:
  + Rename quantumclient to neutronclient
* Mon Jul  1 2013 opensuse-cloud@opensuse.org
- Update to version 2.2.2.17:
  + Enables H404 check (multi line docstring) in flake8
  + Remove the monkey patching of _ into the builtins.
* Sat Jun 29 2013 opensuse-cloud@opensuse.org
- Update to version 2.2.2.13:
  + Support router-interface-add/delete by port_id
  + Allow subnet name in lb-vip-create and lb-pool-create
* Tue Jun 18 2013 speilicke@suse.com
- Only depend on python-discover on SLE, it's a Python-2.6 feature
  backport
* Thu Jun 13 2013 dmueller@suse.com
- update doc file names
* Wed Jun 12 2013 dmueller@suse.com
- fix test dependencies
* Sat Jun  1 2013 dmueller@suse.com
- remove distribute dependency
* Mon May 27 2013 dmueller@suse.com
- python-pbr/d2to1 requires
* Fri Apr 26 2013 speilicke@suse.com
- Buildrequire iso8601, fixes some doc building warnings
- Stop owning %%{python_sitelib}/quantumclient/tests, those all moved
  to the global tests/ dir (in the tarball), which are part of the
  test sub-package
* Mon Mar 25 2013 cloud-devel@suse.de
- Update to version 2.2.0.7+git.1364209145.bed3373:
  + Improve unit tests for python-quantumclient
* Thu Mar 21 2013 cloud-devel@suse.de
- Update to version 2.2.0.5+git.1363880559.fb2ed4e:
  + Add a missing command line option: --insecure
  + add  2.2.0 release note in index.rst file
  + Improve unit tests for python-quantumclient
* Tue Mar 12 2013 dmueller@suse.com
- Update to version 2.2.0:
  + no change
* Mon Mar 11 2013 dmueller@suse.com
- Update to version 2.1.2.9+git.1363006690.f96219d:
  + Update cliff dependency (1.3.1)
  + rename port to port_protocol for lbaas cli
  + Client for agent scheduler extension
  + Add pagination support for client
  + quantumclient.common.serializer module cleanup
  + Rename source_(group_id/ip_prefix) to remote_(group_id/ip_prefix)
  + Add support for security group quotas
  + Fix a description of floatingip-id in (dis)associate commands
* Mon Feb 25 2013 dmueller@suse.com
- add python-prettytable-0.7x.diff:
  * Support prettytable 0.7 as well
* Sun Feb 24 2013 cloud-devel@suse.de
- Update to version 3.0.a1.9+git.1361730043.d77f862:
  + Match other python-*client prettytable dependency
  + Client for agent extension
  + Allow known options after unknown ones in list and update command
  + CLI support for network gateway feature
* Fri Feb 22 2013 saschpe@suse.de
- BuildRequire openstack-suse-macros instead of openstack-macros
* Mon Feb 18 2013 cloud-devel@suse.de
- Update to version 3.0.a1.3+git.1361180468.0879059:
  + Support XML request format
  + Stored the quantum commands list to the variable.
  + Add .coveragerc
  + Add exceptions messages for authentication
  + Add nvp queue support to client
* Mon Feb 11 2013 cloud-devel@suse.de
- Update to version 2.1.44+git.1360595570.dad11b3:
  + Migrate from nose to testr
  + Remove gettext.install from quantumclient.__init__
  + Allow ability to remove security groups from ports
* Mon Feb  4 2013 dmueller@suse.com
- Update to version 2.1.40+git.1359979898.2bca8ee:
  + Fix quantum client example
  + Exception should raise with status code
  + Remove multiple white spaces
  + Delete network with id in sample code using API.
  + The change implements LBaaS CLI commands.
* Thu Jan 17 2013 cloud-devel@suse.de
- Update to version 2.1.33+git.1358431986.798d2c7:
  + Display security group name in security-group-rule-list
  + Migrate from unittest to testtools
* Thu Jan 17 2013 vuntz@suse.com
- Use version-regexp param for git_tarballs service to avoid
  uselessly including the last git commit id twice.
* Mon Jan 14 2013 cloud-devel@suse.de
- Update to version 2.1.28.gd935757+git.1358165388.d935757:
  + Allow known options defined after position arguments.
  + Display subnet cidr information in net-list
  + Fix import order nits
- Build HTML documentation
* Mon Jan  7 2013 cloud-devel@suse.de
- Update to version 2.1.22.g2693515+git.1357543818.2693515:
  + Add file 'ChangeLog' to MANIFEST.in
  + bug 1091028
  + Support dash-style options for security-group commands.
  + Add --dns-nameserver, --host-route, --disable-dhcp to subnet-create
  + Fix a wrong substition for '-h' in bash completion
  + Ensures that help alignment is not hard coded
  + Display columns in the order of -c options
  + Add --router and --floatingip to quota-update options.
  + Correct the verbose output formatting when creating routers.
  + Convenience cmds for l3
  + Fix curl command for PUT and DELETE.
* Wed Dec  5 2012 saschpe@suse.de
- Use @PARENT_TAG@ in _service file to automate versioning
* Tue Nov 20 2012 saschpe@suse.de
- Add test package requirement on:
  + python-openstack.nose_plugin
* Thu Nov 15 2012 saschpe@suse.de
- Use openstack-macros
- Add additional requires for testsuite
* Fri Nov  9 2012 saschpe@suse.de
- Downgrade version to new upstream scheme: 2.1 (bnc#787387)
* Thu Nov  8 2012 saschpe@suse.de
- Drop from_vcs build flag
* Fri Oct 12 2012 vuntz@suse.com
- Update to version 2012.2 (Folsom), which is really 2.1:
  + See https://github.com/openstack/python-quantumclient/commits/2.1
- Buildrequire python-base instead of python-devel:
  + Sufficient for Python-only modules (containing no C/C++ code)
- Buildrequire python-distribute instead of python-setuptools
* Mon Oct  1 2012 jenkins@suse.de
- Update to latest git (3e19fc0):
  + Fix printout of dns name servers and host routes
  + *-list command shows only limited fields normally.
  + update error message to make clear that we were search for a name.
  + router/floating commands support resource reference by name
  + Send all options with CreateFloatingIP
  + prevent floatingip-show and floatingip-delete from querying by "name"
  + Limit list command for router and floating ip
  + Support shared option in CLI
  + Add document for using quantum client by python or cli invocation.
  + fix a minor comment error
  + clean the descriptions for quota cli commands.
* Fri Aug 24 2012 jenkins@suse.de
- Update to latest git (5f21195):
  + Change '_' to '-' in options
* Thu Aug 23 2012 jenkins@suse.de
- Update to latest git (c9316ca):
  + Add nosehtmloutput as a test dependency.
  + initial client + CLI support for routers + floating ips
* Thu Aug 23 2012 jenkins@suse.de
- Update to latest git (54fae9e):
  + Fix warning when creating the sdist package.
* Sun Aug 19 2012 jenkins@suse.de
- Update to latest git (f574f77):
  + Add install_requires in setuptools.setup().
* Tue Aug 14 2012 jenkins@suse.de
- Update to latest git (fa84c93):
  + Refreshes keystone token if a token is expired.
  + add ext list and show commands.
  + Support --no-gateway option
* Mon Aug 13 2012 jenkins@suse.de
- Update to latest git (67fbdea):
  + update mailing list, etc in setup.py
  + remove cli.app in quantum client error message.
  + add pyparsing to pip-requires
* Sun Aug 12 2012 jenkins@suse.de
- Update to latest git (95639d4):
  + Add quota commands to change quota of a tenant.
  + deal with -c option when the list result is empty.
  + enable -h | --help after command to show the command usage.
* Wed Aug  8 2012 jenkins@suse.de
- Update to latest git (defb548):
  + Add name or id to quantum cli commands. Bug #1030180
* Fri Jul 27 2012 cthiel@suse.com
- add requires to python-cliff
* Thu Jul 26 2012 jenkins@suse.de
- Update to latest git (d16e00a):
  + Allow to retrieve objects by name
* Thu Jul 26 2012 jenkins@suse.de
- Update to latest git (d70620c):
  + quit and print usage when unsupported version specified.
  + Add initial docs.
  + add keystone support, new command interface, API v2.0
  + add --fixed-ip argument to create port
  + Add post-tag versioning.
  + Make quantum cli consistent with other cli's practice.
  + Support allocation pools for subnet
  + Use -h, --help to show help messages.
  + Remove quantum client codes for API v1.0 Bug #1021546
* Thu Jul 26 2012 saschpe@suse.de
- Require python-setuptools, /usr/bin/quantum needs it
* Wed Jun 27 2012 saschpe@suse.de
- Change versioning scheme to $release+git.$AUTHORDATE.$COMMITREV
- Simplify from_vcs macros
* Tue Jun 26 2012 saschpe@suse.de
- Consistent package summaries
- Macro cleanup:
  + Package is noarch except for SLE-11
- Added rpmlintrc for non-issues
- Use correct upstream URL
* Thu May 24 2012 jfehlig@suse.com
- Add 'Requires: python >= 2.6.8'
* Fri Feb 24 2012 aspiers@suse.com
- include LICENSE and README
* Wed Jan 25 2012 iartarisi@suse.cz
- initial package
